package com.smcic.api.conference.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.smcic.api.conference.entity.ConferenceAgenda;
import com.smcic.api.conference.entity.ConferenceAgendaDetail;
import com.smcic.api.conference.mapper.ConferenceAgendaMapper;
import com.smcic.api.conference.service.IConferenceAgendaService;
import com.smcic.core.advice.BizException;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author syj
 * @since 2024-03-27
 */
@Service
public class ConferenceAgendaServiceImpl extends ServiceImpl<ConferenceAgendaMapper, ConferenceAgenda> implements IConferenceAgendaService {
    @Resource
    private ConferenceAgendaDetailServiceImpl conferenceAgendaDetailService;

    @Resource
    private ConferenceAclDataServiceImpl aclDataService;


    public List<ConferenceAgenda>  listByCid(Long id){
        return lambdaQuery().eq(ConferenceAgenda::getConferenceId, id).orderByAsc(ConferenceAgenda::getAgendaTime).list();
    }

    public ConferenceAgenda info(Long id){
        ConferenceAgenda conferenceAgenda = getById(id);
        conferenceAgenda.setDetails(conferenceAgendaDetailService.lambdaQuery().eq(ConferenceAgendaDetail::getAgendaId, id).list());
        return conferenceAgenda;
    }

    public ConferenceAgenda create(ConferenceAgenda conferenceAgenda){
        if(!aclDataService.hasDataAcl(conferenceAgenda.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }
        conferenceAgenda.setCreateTime(LocalDateTime.now());
        save(conferenceAgenda);
        return conferenceAgenda;
    }

    public void update(ConferenceAgenda conferenceAgenda){
        ConferenceAgenda data = getById(conferenceAgenda.getId());
        if(!aclDataService.hasDataAcl(conferenceAgenda.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }

        data.setAgendaName(conferenceAgenda.getAgendaName());
        data.setAgendaCover(conferenceAgenda.getAgendaCover());
        data.setAgendaDesc(conferenceAgenda.getAgendaDesc());
        data.setAgendaTime(conferenceAgenda.getAgendaTime());
        data.setAgendaContent(conferenceAgenda.getAgendaContent());
        data.setAgendaVideo(conferenceAgenda.getAgendaVideo());
        data.setWxVideoUid(conferenceAgenda.getWxVideoUid());

        updateById(data);
    }

    public void del(Long id){
        ConferenceAgenda data = getById(id);
        if(!aclDataService.hasDataAcl(data.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }
        removeById(id);
    }
}
