package com.smcic.api.conference.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.smcic.api.conference.entity.ConferenceConf;
import com.smcic.api.conference.mapper.ConferenceConfMapper;
import com.smcic.api.conference.service.IConferenceConfService;
import com.smcic.core.advice.BizException;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author syj
 * @since 2024-03-27
 */
@Service
public class ConferenceConfServiceImpl extends ServiceImpl<ConferenceConfMapper, ConferenceConf> implements IConferenceConfService {

    @Resource
    private ConferenceAclDataServiceImpl aclDataService;

    public ConferenceConf info(Long id, String key) {
        return lambdaQuery().eq(ConferenceConf::getConferenceId, id).eq(ConferenceConf::getConfKey, key).one();
    }

    public List<ConferenceConf> listByCid(Long id){
        return lambdaQuery().eq(ConferenceConf::getConferenceId, id).list();
    }

    public List<ConferenceConf> listByType(Long id, String type){
        return lambdaQuery().eq(ConferenceConf::getConferenceId, id).eq(ConferenceConf::getConfType, type).list();
    }

    public ConferenceConf create(ConferenceConf conferenceConf){
        if(!aclDataService.hasDataAcl(conferenceConf.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }
        save(conferenceConf);
        return conferenceConf;
    }

    public void update(ConferenceConf conferenceConf){
        ConferenceConf conf = getById(conferenceConf.getId());
        if(!aclDataService.hasDataAcl(conf.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }

        conf.setConfKey(conf.getConfKey());
        conf.setConfName(conf.getConfName());
        conf.setConfContent(conferenceConf.getConfContent());
        conf.setConfType(conf.getConfType());

        updateById(conferenceConf);
    }

    public void del(Long id){
        ConferenceConf conf = getById(id);
        if(!aclDataService.hasDataAcl(conf.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }
        removeById(id);
    }
}
