package com.smcic.api.conference.service.impl;

import com.smcic.api.conference.entity.ConferenceGuest;
import com.smcic.api.conference.mapper.ConferenceGuestMapper;
import com.smcic.api.conference.service.IConferenceGuestService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.smcic.core.advice.BizException;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.RequestBody;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author syj
 * @since 2024-03-27
 */
@Service
public class ConferenceGuestServiceImpl extends ServiceImpl<ConferenceGuestMapper, ConferenceGuest> implements IConferenceGuestService {
    @Resource
    private ConferenceAclDataServiceImpl aclDataService;

    public List<ConferenceGuest> listByType(Long cid,  Integer type) {
        return lambdaQuery().eq(ConferenceGuest::getConferenceId, cid).eq(type > 0, ConferenceGuest::getUserType, type)
                .orderByAsc(ConferenceGuest::getSortNumber).list();
    }

    public ConferenceGuest create( ConferenceGuest conferenceGuest){

        if(!aclDataService.hasDataAcl(conferenceGuest.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }

        save(conferenceGuest);
        return conferenceGuest;
    }

    public void update( ConferenceGuest conferenceGuest){
        ConferenceGuest guest = getById(conferenceGuest.getId());
        if(!aclDataService.hasDataAcl(guest.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }

        guest.setUserName(conferenceGuest.getUserName());
        guest.setTags(conferenceGuest.getTags());
        guest.setPhoto(conferenceGuest.getPhoto());
        guest.setSortNumber(conferenceGuest.getSortNumber());
        guest.setUserDesc(conferenceGuest.getUserDesc());
        guest.setUserType(conferenceGuest.getUserType());
        guest.setSpeechVideo(conferenceGuest.getSpeechVideo());
        guest.setSpeechCover(conferenceGuest.getSpeechCover());
        updateById(guest);
    }

    public void del(Long id){
        ConferenceGuest guest = getById(id);
        if(!aclDataService.hasDataAcl(guest.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }
        removeById(id);
    }
}
