package com.smcic.api.conference.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.smcic.api.conference.dto.BatchPhoto;
import com.smcic.api.conference.dto.DelBatchDTO;
import com.smcic.api.conference.entity.ConferenceLivePhoto;
import com.smcic.api.conference.mapper.ConferenceLivePhotoMapper;
import com.smcic.api.conference.service.IConferenceLivePhotoService;
import com.smcic.core.advice.BizException;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ThreadPoolExecutor;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author syj
 * @since 2024-03-28
 */
@Service
public class ConferenceLivePhotoServiceImpl extends ServiceImpl<ConferenceLivePhotoMapper, ConferenceLivePhoto> implements IConferenceLivePhotoService {

    @Resource
    private ThreadPoolExecutor threadPoolExecutor;

    @Resource
    private SSEService sseService;

    @Resource
    private ConferenceAclDataServiceImpl aclDataService;

    public Page<ConferenceLivePhoto> photoPage(Long id, Integer page, Integer pageSize) {
        Page<ConferenceLivePhoto> page1 = new Page<>(page, pageSize);

        LambdaQueryWrapper<ConferenceLivePhoto> wrapper = new LambdaQueryWrapper<>();
        return this.baseMapper.selectPage(page1, wrapper.eq(ConferenceLivePhoto::getAgendaId, id)
                .orderByDesc(ConferenceLivePhoto::getIsTop)
                .orderByDesc(ConferenceLivePhoto::getId));
    }

    @Transactional
    public void batchCreate(BatchPhoto batchPhoto){
        if(!aclDataService.hasDataAcl(batchPhoto.getConferenceId())){
            throw new BizException("没有权限");
        }
        List<ConferenceLivePhoto> photos = new ArrayList<>();
        LocalDateTime now = LocalDateTime.now();
        for(String url : batchPhoto.getPhoto()){
            ConferenceLivePhoto conferenceLivePhoto = new ConferenceLivePhoto();

            conferenceLivePhoto.setConferenceId(batchPhoto.getConferenceId());
            conferenceLivePhoto.setAgendaId(batchPhoto.getAgendaId());
            conferenceLivePhoto.setTitle(batchPhoto.getTitle());
            conferenceLivePhoto.setPhoto(url);
            conferenceLivePhoto.setCreateTime(now);
            photos.add(conferenceLivePhoto);
        }
        saveBatch(photos);

//        threadPoolExecutor.execute(()-> sseService.sendData(batchPhoto.getConferenceId(), photos));
    }

    //批量删除
    public void delBatch(DelBatchDTO dto) {
        if(!aclDataService.hasDataAcl(dto.getCid())){
            throw new BizException("没有权限");
        }
        remove(new LambdaQueryWrapper<ConferenceLivePhoto>().in(ConferenceLivePhoto::getId, dto.getIds()).eq(ConferenceLivePhoto::getConferenceId, dto.getCid()));
    }
}
