package com.smcic.api.conference.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.smcic.api.conference.entity.ConferenceNews;
import com.smcic.api.conference.mapper.ConferenceNewsMapper;
import com.smcic.api.conference.service.IConferenceNewsService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.smcic.core.advice.BizException;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.RequestBody;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.Arrays;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author syj
 * @since 2024-03-27
 */
@Service
public class ConferenceNewsServiceImpl extends ServiceImpl<ConferenceNewsMapper, ConferenceNews> implements IConferenceNewsService {
    @Resource
    private ConferenceAclDataServiceImpl aclDataService;

    public Page<ConferenceNews> newsPage(Long cid, Integer page, Integer pageSize, String category) {
        Page<ConferenceNews> newsPage = new Page<>(page, pageSize);
        LambdaQueryWrapper<ConferenceNews> wrapper = new LambdaQueryWrapper<>();

        return baseMapper.selectPage(
                newsPage,
                wrapper.eq(ConferenceNews::getConferenceId, cid)
                        .eq(ConferenceNews::getCategory, category)
                        .eq(ConferenceNews::getStatus, 1)
                        .orderByDesc(Arrays.asList(ConferenceNews::getIsTop, ConferenceNews::getPublishTime))
        );
    }

    public List<ConferenceNews>  newsList(Long cid, String category){
        return lambdaQuery().eq(ConferenceNews::getConferenceId, cid).eq(ConferenceNews::getCategory, category).list();
    }


    public ConferenceNews create(ConferenceNews conferenceNews){
        if(!aclDataService.hasDataAcl(conferenceNews.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }
        conferenceNews.setCreateTime(LocalDateTime.now());
        conferenceNews.setUpdateTime(LocalDateTime.now());
        save(conferenceNews);
        return conferenceNews;
    }

    public void update(ConferenceNews conferenceNews){
        ConferenceNews news = getById(conferenceNews.getId());
        if(!aclDataService.hasDataAcl(news.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }

        news.setCover(conferenceNews.getCover());
        news.setTitle(conferenceNews.getTitle());
        news.setSummary(conferenceNews.getSummary());
        news.setContent(conferenceNews.getContent());
        news.setAuthor(conferenceNews.getAuthor());
        news.setSource(conferenceNews.getSource());
        news.setPublishTime(conferenceNews.getPublishTime());

        news.setUpdateTime(LocalDateTime.now());
        news.setIsTop(conferenceNews.getIsTop());
        news.setType(conferenceNews.getType());

        updateById(news);

    }


    public void del(Long id){
        ConferenceNews news = getById(id);
        if(!aclDataService.hasDataAcl(news.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }
        removeById(id);
    }
}
