package com.smcic.api.conference.service.impl;

import com.smcic.api.conference.entity.ConferencePartner;
import com.smcic.api.conference.mapper.ConferencePartnerMapper;
import com.smcic.api.conference.service.IConferencePartnerService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.smcic.core.advice.BizException;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author syj
 * @since 2024-03-28
 */
@Service
public class ConferencePartnerServiceImpl extends ServiceImpl<ConferencePartnerMapper, ConferencePartner> implements IConferencePartnerService {

    @Resource
    private ConferenceAclDataServiceImpl aclDataService;

    public List<ConferencePartner> listByCid(Long cid){
        return lambdaQuery().eq(ConferencePartner::getConferenceId, cid)
                .eq(ConferencePartner::getStatus, 1)
                .orderByAsc(ConferencePartner::getSortNo)
                .orderByAsc(ConferencePartner::getId)
                .list();
    }

    public  ConferencePartner create(ConferencePartner conferencePartner){
        if(!aclDataService.hasDataAcl(conferencePartner.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }
        save(conferencePartner);
        return conferencePartner;
    }

    public void update(ConferencePartner conferencePartner){
        ConferencePartner partner = getById(conferencePartner.getId());
        if(!aclDataService.hasDataAcl(partner.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }
        partner.setPartnerName(conferencePartner.getPartnerName());
        partner.setLogo(conferencePartner.getLogo());
        partner.setPartnerType(conferencePartner.getPartnerType());
        partner.setWebsite(conferencePartner.getWebsite());
        partner.setSortNo(conferencePartner.getSortNo());

        updateById(partner);
    }

    public void del(Long id){
        ConferencePartner partner = getById(id);
        if(!aclDataService.hasDataAcl(partner.getConferenceId())){
            throw new BizException("没有该会议的权限");
        }
        removeById(id);
    }

}
