package com.smcic.api.conference.service.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.lang.UUID;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.smcic.api.conference.entity.Conference;
import com.smcic.api.conference.mapper.ConferenceMapper;
import com.smcic.api.conference.service.IConferenceService;
import com.smcic.api.operate.service.OSSService;
import com.smcic.api.user.entity.User;
import com.smcic.api.user.service.impl.UserServiceImpl;
import com.smcic.core.advice.BizException;
import com.smcic.core.auth.AESUtil;
import com.smcic.core.auth.HttpContextUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author syj
 * @since 2024-03-27
 */
@Service
public class ConferenceServiceImpl extends ServiceImpl<ConferenceMapper, Conference> implements IConferenceService {

    @Resource
    private OSSService ossService;

    @Resource
    private ConferenceAclDataServiceImpl aclDataService;

    @Resource
    private UserServiceImpl userService;

    public String upload(MultipartFile file, Long cid){
        String path = "operate/cenference/" + cid + "/" + (new DateTime().toString("yyyyMMdd")) + "/"+ UUID.randomUUID() + file.getOriginalFilename();
        ossService.put("smcic-index", path, file);

        return  "https://cxzx.smcic.net/" + path;
    }

    public List<String> multiUpload(MultipartFile[] files, Long cid){
        List<String> urls = new ArrayList<>();
        for(MultipartFile file : files){
            urls.add(upload(file, cid));
        }
        return urls;
    }

    @Transactional
    public Conference create( Conference conference){
        Optional<String> token = HttpContextUtil.getToken();
        if (!token.isPresent()) {
            throw new BizException("获取token异常");
        }
        String userId = AESUtil.decryptStr(token.get());
        save(conference);
        aclDataService.create(Long.valueOf(userId), conference.getId());
        return conference;
    }

    public void update(Conference conference){
        if(!aclDataService.hasDataAcl(conference.getId())){
            throw new BizException("没有该会议的权限");
        }

        updateById(conference);
    }

    public  List<Conference> ls(){
        User loginUser = userService.getLoginUser();
        if(loginUser.getRoleId() == 1){
            return list();
        }else{
            List<Long> conferenceIds = aclDataService.getAcl(loginUser.getId());
            if(conferenceIds.isEmpty()){
                return new ArrayList<>();
            }
            return lambdaQuery().in(Conference::getId, conferenceIds).list();
        }

    }
}
