package com.smcic.api.conference.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.smcic.api.conference.entity.ConferenceSubscription;
import com.smcic.api.conference.mapper.ConferenceSubscriptionMapper;
import com.smcic.api.conference.service.IConferenceSubscriptionService;
import com.smcic.core.advice.BizException;
import org.apache.http.util.TextUtils;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author syj
 * @since 2024-03-27
 */
@Service
public class ConferenceSubscriptionServiceImpl extends ServiceImpl<ConferenceSubscriptionMapper, ConferenceSubscription> implements IConferenceSubscriptionService {
    @Resource
    private RedisTemplate<String, String> redisTemplate;

    public ConferenceSubscription create(ConferenceSubscription conferenceSubscription, String code){
        String phone =  redisTemplate.opsForValue().get("WX_CODE_" + code); // 从redis中获取手机号
        if (TextUtils.isEmpty(phone)) {
            throw new BizException("账号已过期,请重新登陆");
        }
        conferenceSubscription.setPhone(phone);
        save(conferenceSubscription);
        return conferenceSubscription;
    }

    public List<ConferenceSubscription> getByCode(Long id, String code){
        String phone =  redisTemplate.opsForValue().get("WX_CODE_" + code); // 从redis中获取手机号
        if (TextUtils.isEmpty(phone)) {
            throw new BizException("账号已过期,请重新登陆");
        }
        return lambdaQuery().eq(ConferenceSubscription::getConferenceId, id).eq(ConferenceSubscription::getPhone, phone)
                .eq(ConferenceSubscription::getStatus, 1).list();
    }

    public Page<ConferenceSubscription> getByCid(Long id, Integer page, Integer pageSize){

        return lambdaQuery().eq(ConferenceSubscription::getConferenceId, id).eq(ConferenceSubscription::getStatus, 1)
                .page(new Page<>(page, pageSize));

    }
}
