package com.smcic.api.hotrank.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;
import com.smcic.api.hotrank.dto.HotRankDTO;
import com.smcic.api.hotrank.entity.HotRank;
import com.smcic.api.hotrank.mapper.HotRankMapper;
import com.smcic.api.hotrank.service.IHotRankService;
import org.springframework.stereotype.Service;

import java.time.format.DateTimeFormatter;
import java.util.List;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author syj
 * @since 2022-04-27
 */
@Service
public class HotRankServiceImpl extends ServiceImpl<HotRankMapper, HotRank> implements IHotRankService {

    private final Cache<String[], List<HotRankDTO>> cache = Caffeine.newBuilder().expireAfterWrite(1, TimeUnit.MINUTES).build();

    public List<HotRankDTO> todayRank(String rank){
        String dt = baseMapper.getLastDt(rank).getDt();

        return cache.get(new String[]{rank,dt}, (key) -> lambdaQuery().eq(HotRank::getDt, key[1]).eq(HotRank::getPlatform, key[0]).orderByAsc(HotRank::getRk).last("limit 50").list()
                .stream().map(data -> new HotRankDTO(data.getContent(), data.getRk(), Long.valueOf(data.getRsCount()),
                        data.getHeatTag(), data.getUrl())).collect(Collectors.toList()));

    }
}
