package com.smcic.api.operate.job;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.smcic.api.operate.entity.KeysConst;
import com.smcic.api.operate.service.impl.OperateServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;

@Component
@Slf4j
public class TaskBootstrap {

    @Resource
    private Kafka2Db kafka2Db;


    @Resource
    private OperateServiceImpl operateService;

    @Resource
    private RedisTemplate<String, String> redisTemplate;

    @Resource
    private ObjectMapper objectMapper;

    @PostConstruct
    public void init(){
        kafka2Db.run();
        log.info("Kafka2Db init-----------------------------------");
    }

    @Scheduled(fixedRate = 1000 * 600)
    public void operate2cache(){
        operateService.list().forEach(operate -> {
            try {
                redisTemplate.opsForValue().set(KeysConst.OPERATE + operate.getOperateId(), objectMapper.writeValueAsString(operate));
            } catch (JsonProcessingException e) {
                log.error("活动写入缓存失败", e);
            }
        });
    }
}
